#!/bin/sh
### BEGIN INIT INFO
# Provides:          m-bus
# Required-Start:    networking
# Required-Stop:     networking
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start the M-Bus daemon.
### END INIT INFO


export PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
DAEMON=/usr/local/sbin/m-bus
NAME=m-bus
DESC="M-Bus daemon"
PIDFILE=/var/run/$NAME.pid
SCRIPTNAME=/etc/init.d/$NAME.sh

CRONRRD="/etc/cron.hourly/2-rrd-graph"
CRONCSV="/etc/cron.hourly/2-csv-index"
UCONFIG="/usr/local/etc/rrd/m-bus.conf"
DAEMON_OPTS="-v -w -c $UCONFIG -l /tmp/m-bus.log -e /tmp/m-bus.err"

test -x $DAEMON || exit 0

set -e

. /lib/lsb/init-functions
. /usr/local/etc/rrd/rrd.conf

case "$1" in
  start)
	log_daemon_msg "Starting $DESC" $NAME

	if [ ! -d /tmp/mbus ]
	then
		# Restore old files
		mkdir /tmp/mbus
		cp -p $RRD_DATA/*.rrd /tmp/mbus 2>/dev/null || true
	fi

	if ! start-stop-daemon --quiet --start \
	--background --make-pidfile --pidfile $PIDFILE --exec $DAEMON -- $DAEMON_OPTS ; then
            log_end_msg 1
	else
            log_end_msg 0
	fi
	;;
  stop)
	log_daemon_msg "Stopping $DESC" $NAME
	if start-stop-daemon --quiet --stop --oknodo --retry 30\
	--pidfile $PIDFILE --exec $DAEMON; then
	    rm -f $PIDFILE
	    log_end_msg 0
	else
	    log_end_msg 1
	fi

	# Backup current data from ram disk
	if [ -d /tmp/mbus ]
	then
		test -x /etc/cron.hourly/1-mbus-flush &&\
		 /etc/cron.hourly/1-mbus-flush stop
		cp /tmp/mbus/*.rrd $RRD_DATA || echo "Warning: No RRD files copied to flash."
	fi
	;;
  restart|reload)
	$0 stop

	# Rebuild all rrd files
	test "$1" = "reload" &&\
	rm -f /usr/local/etc/rrd/mbus-*-*.conf \
		$RRD_DATA/mbus-*-*.rrd \
		/tmp/mbus/mbus-*-*.rrd

	# Disable CronJob, if RRD is diabled
	ENABLE=`sed -ne 's/^rrd\.enable *= *\([01]\).*$/\1/p' <$UCONFIG`
	case "$ENABLE" in
	    0)
		chmod a-x $CRONRRD
		;;
	    1)
		chmod a+x $CRONRRD
		;;
	esac

	# Disable CronJob, if CSV is diabled
	ENABLE=`sed -ne 's/^csv\.enable *= *\([01]\).*$/\1/p' <$UCONFIG`
	case "$ENABLE" in
	    0)
		chmod a-x $CRONCSV
		rm -f $RRD_CSV/index.html
		;;
	    1)
		chmod a+x $CRONCSV
		;;
	esac

	$0 start
	;;
  *)
	echo "Usage: $SCRIPTNAME {start|stop|restart|reload}" >&2
	exit 1
	;;
esac

exit 0
