#!/bin/sh

# Script builds diagrams.
# $1: optional RRD config file name without path and witout exetension (mbus-*-*)
# $2: optional start (24h, 7d, 31d, 60d, 90d, ...)

exec 2>/tmp/rrd-graph.err

. /usr/local/etc/rrd/rrd.conf

umask 022

# $1: basename
# $2: Start time
graph()
{
    . /usr/local/etc/rrd/$1.conf

    TMP_FILE="/tmp/mbus/$1.rrd"
    RRD_FILE="$RRD_DATA/$1.rrd"

    if [ $TMP_FILE -nt $RRD_FILE -o ! -f $RRD_FILE ]
    then
	cp -p $TMP_FILE $RRD_FILE
    fi

    # Cached for web view
    if [ $RRD_FILE -nt $RRD_IMG/$1-$2.png -o ! -f $RRD_IMG/$1-$2.png ]
    then
	logger -t rrd-graph -p user.info "build $1-$2.png"
	nice rrdtool graph \
		$RRD_IMG/$1-$2.png \
		DEF:cnt=$RRD_FILE:$RRD_NAME:AVERAGE \
		"LINE2:cnt#FF0000" \
		"COMMENT:`date '+%F %H.%M'`" \
		--title "$RRD_TITLE" \
		--vertical-label "$RRD_VERTLABEL" \
		--imgformat PNG \
		--lazy \
		--start -$2 >/dev/null
    fi
}

rebuild()
{
	if [ -n "$2" ]
	then
		# single file
		graph $1 $2
	else
		# all files
		graph $1 24h
		graph $1 7d
		graph $1 31d
		graph $1 60d
		graph $1 90d
	fi
}

if [ -n "$1" ]
then
	# Rebuild single file
	rebuild $1 $2
else
	# Search for all files
	for name in /usr/local/etc/rrd/mbus-*-*.conf
	do
		rebuild `basename "$name" .conf` $2
	done
fi
